# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vpool/v1/event.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14vpool/v1/event.proto\x12\x0fnibiru.vpool.v1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb6\x01\n\x19ReserveSnapshotSavedEvent\x12\x0c\n\x04pair\x18\x01 \x01(\t\x12\x45\n\rquote_reserve\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x44\n\x0c\x62\x61se_reserve\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\xb0\x01\n\x15SwapQuoteForBaseEvent\x12\x0c\n\x04pair\x18\x01 \x01(\t\x12\x44\n\x0cquote_amount\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x43\n\x0b\x62\x61se_amount\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\xb0\x01\n\x15SwapBaseForQuoteEvent\x12\x0c\n\x04pair\x18\x01 \x01(\t\x12\x44\n\x0cquote_amount\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x43\n\x0b\x62\x61se_amount\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\x98\x01\n\x10MarkPriceChanged\x12\x0c\n\x04pair\x18\x01 \x01(\t\x12=\n\x05price\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x37\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\x90\xdf\x1f\x01\xc8\xde\x1f\x00\x42-Z+github.com/NibiruChain/nibiru/x/vpool/typesb\x06proto3')



_RESERVESNAPSHOTSAVEDEVENT = DESCRIPTOR.message_types_by_name['ReserveSnapshotSavedEvent']
_SWAPQUOTEFORBASEEVENT = DESCRIPTOR.message_types_by_name['SwapQuoteForBaseEvent']
_SWAPBASEFORQUOTEEVENT = DESCRIPTOR.message_types_by_name['SwapBaseForQuoteEvent']
_MARKPRICECHANGED = DESCRIPTOR.message_types_by_name['MarkPriceChanged']
ReserveSnapshotSavedEvent = _reflection.GeneratedProtocolMessageType('ReserveSnapshotSavedEvent', (_message.Message,), {
  'DESCRIPTOR' : _RESERVESNAPSHOTSAVEDEVENT,
  '__module__' : 'vpool.v1.event_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.vpool.v1.ReserveSnapshotSavedEvent)
  })
_sym_db.RegisterMessage(ReserveSnapshotSavedEvent)

SwapQuoteForBaseEvent = _reflection.GeneratedProtocolMessageType('SwapQuoteForBaseEvent', (_message.Message,), {
  'DESCRIPTOR' : _SWAPQUOTEFORBASEEVENT,
  '__module__' : 'vpool.v1.event_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.vpool.v1.SwapQuoteForBaseEvent)
  })
_sym_db.RegisterMessage(SwapQuoteForBaseEvent)

SwapBaseForQuoteEvent = _reflection.GeneratedProtocolMessageType('SwapBaseForQuoteEvent', (_message.Message,), {
  'DESCRIPTOR' : _SWAPBASEFORQUOTEEVENT,
  '__module__' : 'vpool.v1.event_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.vpool.v1.SwapBaseForQuoteEvent)
  })
_sym_db.RegisterMessage(SwapBaseForQuoteEvent)

MarkPriceChanged = _reflection.GeneratedProtocolMessageType('MarkPriceChanged', (_message.Message,), {
  'DESCRIPTOR' : _MARKPRICECHANGED,
  '__module__' : 'vpool.v1.event_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.vpool.v1.MarkPriceChanged)
  })
_sym_db.RegisterMessage(MarkPriceChanged)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/NibiruChain/nibiru/x/vpool/types'
  _RESERVESNAPSHOTSAVEDEVENT.fields_by_name['quote_reserve']._options = None
  _RESERVESNAPSHOTSAVEDEVENT.fields_by_name['quote_reserve']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _RESERVESNAPSHOTSAVEDEVENT.fields_by_name['base_reserve']._options = None
  _RESERVESNAPSHOTSAVEDEVENT.fields_by_name['base_reserve']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _SWAPQUOTEFORBASEEVENT.fields_by_name['quote_amount']._options = None
  _SWAPQUOTEFORBASEEVENT.fields_by_name['quote_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _SWAPQUOTEFORBASEEVENT.fields_by_name['base_amount']._options = None
  _SWAPQUOTEFORBASEEVENT.fields_by_name['base_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _SWAPBASEFORQUOTEEVENT.fields_by_name['quote_amount']._options = None
  _SWAPBASEFORQUOTEEVENT.fields_by_name['quote_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _SWAPBASEFORQUOTEEVENT.fields_by_name['base_amount']._options = None
  _SWAPBASEFORQUOTEEVENT.fields_by_name['base_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MARKPRICECHANGED.fields_by_name['price']._options = None
  _MARKPRICECHANGED.fields_by_name['price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MARKPRICECHANGED.fields_by_name['timestamp']._options = None
  _MARKPRICECHANGED.fields_by_name['timestamp']._serialized_options = b'\220\337\037\001\310\336\037\000'
  _RESERVESNAPSHOTSAVEDEVENT._serialized_start=156
  _RESERVESNAPSHOTSAVEDEVENT._serialized_end=338
  _SWAPQUOTEFORBASEEVENT._serialized_start=341
  _SWAPQUOTEFORBASEEVENT._serialized_end=517
  _SWAPBASEFORQUOTEEVENT._serialized_start=520
  _SWAPBASEFORQUOTEEVENT._serialized_end=696
  _MARKPRICECHANGED._serialized_start=699
  _MARKPRICECHANGED._serialized_end=851
# @@protoc_insertion_point(module_scope)
