# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/protobuf/any.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19google/protobuf/any.proto\x12\x0fgoogle.protobuf\x1a\x14gogoproto/gogo.proto\"8\n\x03\x41ny\x12\x10\n\x08type_url\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x10\xf0\xa1\x1f\x00\x98\xa0\x1f\x00\xb0\xa0\x1f\x00\x80\xdc \x00\x42S\n\x13\x63om.google.protobufB\x08\x41nyProtoP\x01Z\x05types\xa2\x02\x03GPB\xaa\x02\x1eGoogle.Protobuf.WellKnownTypes\xc0\xe3\x1e\x00\x62\x06proto3')



_ANY = DESCRIPTOR.message_types_by_name['Any']
Any = _reflection.GeneratedProtocolMessageType('Any', (_message.Message,), {
  'DESCRIPTOR' : _ANY,
  '__module__' : 'google.protobuf.any_pb2'
  # @@protoc_insertion_point(class_scope:google.protobuf.Any)
  })
_sym_db.RegisterMessage(Any)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\023com.google.protobufB\010AnyProtoP\001Z\005types\242\002\003GPB\252\002\036Google.Protobuf.WellKnownTypes\300\343\036\000'
  _ANY._options = None
  _ANY._serialized_options = b'\360\241\037\000\230\240\037\000\260\240\037\000\200\334 \000'
  _ANY._serialized_start=68
  _ANY._serialized_end=124
# @@protoc_insertion_point(module_scope)
