# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from stablecoin import query_pb2 as stablecoin_dot_query__pb2


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Params = channel.unary_unary(
                '/nibiru.stablecoin.v1.Query/Params',
                request_serializer=stablecoin_dot_query__pb2.QueryParamsRequest.SerializeToString,
                response_deserializer=stablecoin_dot_query__pb2.QueryParamsResponse.FromString,
                )
        self.ModuleAccountBalances = channel.unary_unary(
                '/nibiru.stablecoin.v1.Query/ModuleAccountBalances',
                request_serializer=stablecoin_dot_query__pb2.QueryModuleAccountBalances.SerializeToString,
                response_deserializer=stablecoin_dot_query__pb2.QueryModuleAccountBalancesResponse.FromString,
                )
        self.CirculatingSupplies = channel.unary_unary(
                '/nibiru.stablecoin.v1.Query/CirculatingSupplies',
                request_serializer=stablecoin_dot_query__pb2.QueryCirculatingSupplies.SerializeToString,
                response_deserializer=stablecoin_dot_query__pb2.QueryCirculatingSuppliesResponse.FromString,
                )
        self.LiquidityRatioInfo = channel.unary_unary(
                '/nibiru.stablecoin.v1.Query/LiquidityRatioInfo',
                request_serializer=stablecoin_dot_query__pb2.QueryLiquidityRatioInfoRequest.SerializeToString,
                response_deserializer=stablecoin_dot_query__pb2.QueryLiquidityRatioInfoResponse.FromString,
                )


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def Params(self, request, context):
        """Parameters queries the parameters of the x/stablecoin module.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ModuleAccountBalances(self, request, context):
        """ModuleAccountBalances queries the account balance of x/stablecoin.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CirculatingSupplies(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LiquidityRatioInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Params': grpc.unary_unary_rpc_method_handler(
                    servicer.Params,
                    request_deserializer=stablecoin_dot_query__pb2.QueryParamsRequest.FromString,
                    response_serializer=stablecoin_dot_query__pb2.QueryParamsResponse.SerializeToString,
            ),
            'ModuleAccountBalances': grpc.unary_unary_rpc_method_handler(
                    servicer.ModuleAccountBalances,
                    request_deserializer=stablecoin_dot_query__pb2.QueryModuleAccountBalances.FromString,
                    response_serializer=stablecoin_dot_query__pb2.QueryModuleAccountBalancesResponse.SerializeToString,
            ),
            'CirculatingSupplies': grpc.unary_unary_rpc_method_handler(
                    servicer.CirculatingSupplies,
                    request_deserializer=stablecoin_dot_query__pb2.QueryCirculatingSupplies.FromString,
                    response_serializer=stablecoin_dot_query__pb2.QueryCirculatingSuppliesResponse.SerializeToString,
            ),
            'LiquidityRatioInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.LiquidityRatioInfo,
                    request_deserializer=stablecoin_dot_query__pb2.QueryLiquidityRatioInfoRequest.FromString,
                    response_serializer=stablecoin_dot_query__pb2.QueryLiquidityRatioInfoResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nibiru.stablecoin.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def Params(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.stablecoin.v1.Query/Params',
            stablecoin_dot_query__pb2.QueryParamsRequest.SerializeToString,
            stablecoin_dot_query__pb2.QueryParamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ModuleAccountBalances(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.stablecoin.v1.Query/ModuleAccountBalances',
            stablecoin_dot_query__pb2.QueryModuleAccountBalances.SerializeToString,
            stablecoin_dot_query__pb2.QueryModuleAccountBalancesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CirculatingSupplies(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.stablecoin.v1.Query/CirculatingSupplies',
            stablecoin_dot_query__pb2.QueryCirculatingSupplies.SerializeToString,
            stablecoin_dot_query__pb2.QueryCirculatingSuppliesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LiquidityRatioInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.stablecoin.v1.Query/LiquidityRatioInfo',
            stablecoin_dot_query__pb2.QueryLiquidityRatioInfoRequest.SerializeToString,
            stablecoin_dot_query__pb2.QueryLiquidityRatioInfoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
