# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from lockup.v1 import tx_pb2 as lockup_dot_v1_dot_tx__pb2


class MsgStub(object):
    """Msg defines the Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.LockTokens = channel.unary_unary(
                '/nibiru.lockup.v1.Msg/LockTokens',
                request_serializer=lockup_dot_v1_dot_tx__pb2.MsgLockTokens.SerializeToString,
                response_deserializer=lockup_dot_v1_dot_tx__pb2.MsgLockTokensResponse.FromString,
                )
        self.InitiateUnlock = channel.unary_unary(
                '/nibiru.lockup.v1.Msg/InitiateUnlock',
                request_serializer=lockup_dot_v1_dot_tx__pb2.MsgInitiateUnlock.SerializeToString,
                response_deserializer=lockup_dot_v1_dot_tx__pb2.MsgInitiateUnlockResponse.FromString,
                )
        self.Unlock = channel.unary_unary(
                '/nibiru.lockup.v1.Msg/Unlock',
                request_serializer=lockup_dot_v1_dot_tx__pb2.MsgUnlock.SerializeToString,
                response_deserializer=lockup_dot_v1_dot_tx__pb2.MsgUnlockResponse.FromString,
                )


class MsgServicer(object):
    """Msg defines the Msg service.
    """

    def LockTokens(self, request, context):
        """LockTokens lock tokens
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InitiateUnlock(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Unlock(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'LockTokens': grpc.unary_unary_rpc_method_handler(
                    servicer.LockTokens,
                    request_deserializer=lockup_dot_v1_dot_tx__pb2.MsgLockTokens.FromString,
                    response_serializer=lockup_dot_v1_dot_tx__pb2.MsgLockTokensResponse.SerializeToString,
            ),
            'InitiateUnlock': grpc.unary_unary_rpc_method_handler(
                    servicer.InitiateUnlock,
                    request_deserializer=lockup_dot_v1_dot_tx__pb2.MsgInitiateUnlock.FromString,
                    response_serializer=lockup_dot_v1_dot_tx__pb2.MsgInitiateUnlockResponse.SerializeToString,
            ),
            'Unlock': grpc.unary_unary_rpc_method_handler(
                    servicer.Unlock,
                    request_deserializer=lockup_dot_v1_dot_tx__pb2.MsgUnlock.FromString,
                    response_serializer=lockup_dot_v1_dot_tx__pb2.MsgUnlockResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nibiru.lockup.v1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the Msg service.
    """

    @staticmethod
    def LockTokens(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.lockup.v1.Msg/LockTokens',
            lockup_dot_v1_dot_tx__pb2.MsgLockTokens.SerializeToString,
            lockup_dot_v1_dot_tx__pb2.MsgLockTokensResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InitiateUnlock(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.lockup.v1.Msg/InitiateUnlock',
            lockup_dot_v1_dot_tx__pb2.MsgInitiateUnlock.SerializeToString,
            lockup_dot_v1_dot_tx__pb2.MsgInitiateUnlockResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Unlock(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.lockup.v1.Msg/Unlock',
            lockup_dot_v1_dot_tx__pb2.MsgUnlock.SerializeToString,
            lockup_dot_v1_dot_tx__pb2.MsgUnlockResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
