# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pricefeed/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from pricefeed import params_pb2 as pricefeed_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15pricefeed/query.proto\x12\x13nibiru.pricefeed.v1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x16pricefeed/params.proto\"\x14\n\x12QueryParamsRequest\"N\n\x13QueryParamsResponse\x12\x31\n\x06params\x18\x01 \x01(\x0b\x32\x1b.nibiru.pricefeed.v1.ParamsB\x04\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\"*\n\x11QueryPriceRequest\x12\x0f\n\x07pair_id\x18\x01 \x01(\t:\x04\x88\xa0\x1f\x00\"Z\n\x12QueryPriceResponse\x12>\n\x05price\x18\x01 \x01(\x0b\x32).nibiru.pricefeed.v1.CurrentPriceResponseB\x04\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\"\x14\n\x12QueryPricesRequest\"u\n\x13QueryPricesResponse\x12X\n\x06prices\x18\x01 \x03(\x0b\x32).nibiru.pricefeed.v1.CurrentPriceResponseB\x1d\xaa\xdf\x1f\x15\x43urrentPriceResponses\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\".\n\x15QueryRawPricesRequest\x12\x0f\n\x07pair_id\x18\x01 \x01(\t:\x04\x88\xa0\x1f\x00\"z\n\x16QueryRawPricesResponse\x12Z\n\nraw_prices\x18\x01 \x03(\x0b\x32(.nibiru.pricefeed.v1.PostedPriceResponseB\x1c\xaa\xdf\x1f\x14PostedPriceResponses\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\",\n\x13QueryOraclesRequest\x12\x0f\n\x07pair_id\x18\x01 \x01(\t:\x04\x88\xa0\x1f\x00\"-\n\x14QueryOraclesResponse\x12\x0f\n\x07oracles\x18\x01 \x03(\t:\x04\x88\xa0\x1f\x00\"\x15\n\x13QueryMarketsRequest\"[\n\x14QueryMarketsResponse\x12=\n\x07markets\x18\x01 \x03(\x0b\x32\x1b.nibiru.pricefeed.v1.MarketB\x0f\xaa\xdf\x1f\x07Markets\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\"\xbf\x01\n\x13PostedPriceResponse\x12\x1b\n\x07pair_id\x18\x01 \x01(\tB\n\xe2\xde\x1f\x06PairID\x12\x16\n\x0eoracle_address\x18\x02 \x01(\t\x12=\n\x05price\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x34\n\x06\x65xpiry\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\x90\xdf\x1f\x01\xc8\xde\x1f\x00\"r\n\x14\x43urrentPriceResponse\x12\x1b\n\x07pair_id\x18\x01 \x01(\tB\n\xe2\xde\x1f\x06PairID\x12=\n\x05price\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"F\n\x06Market\x12\x1b\n\x07pair_id\x18\x01 \x01(\tB\n\xe2\xde\x1f\x06PairID\x12\x0f\n\x07oracles\x18\x02 \x03(\t\x12\x0e\n\x06\x61\x63tive\x18\x03 \x01(\x08\x32\x84\x07\n\x05Query\x12\x8a\x01\n\x0bQueryParams\x12\'.nibiru.pricefeed.v1.QueryParamsRequest\x1a(.nibiru.pricefeed.v1.QueryParamsResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /nibiru/pricefeed/v1beta1/params\x12\x91\x01\n\nQueryPrice\x12&.nibiru.pricefeed.v1.QueryPriceRequest\x1a\'.nibiru.pricefeed.v1.QueryPriceResponse\"2\x82\xd3\xe4\x93\x02,\x12*/nibiru/pricefeed/v1beta1/prices/{pair_id}\x12\x8a\x01\n\x0bQueryPrices\x12\'.nibiru.pricefeed.v1.QueryPricesRequest\x1a(.nibiru.pricefeed.v1.QueryPricesResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /nibiru/pricefeed/v1beta1/prices\x12\xa0\x01\n\x0eQueryRawPrices\x12*.nibiru.pricefeed.v1.QueryRawPricesRequest\x1a+.nibiru.pricefeed.v1.QueryRawPricesResponse\"5\x82\xd3\xe4\x93\x02/\x12-/nibiru/pricefeed/v1beta1/rawprices/{pair_id}\x12\x98\x01\n\x0cQueryOracles\x12(.nibiru.pricefeed.v1.QueryOraclesRequest\x1a).nibiru.pricefeed.v1.QueryOraclesResponse\"3\x82\xd3\xe4\x93\x02-\x12+/nibiru/pricefeed/v1beta1/oracles/{pair_id}\x12\x8e\x01\n\x0cQueryMarkets\x12(.nibiru.pricefeed.v1.QueryMarketsRequest\x1a).nibiru.pricefeed.v1.QueryMarketsResponse\")\x82\xd3\xe4\x93\x02#\x12!/nibiru/pricefeed/v1beta1/marketsB9Z/github.com/NibiruChain/nibiru/x/pricefeed/types\xa8\xe2\x1e\x01\xe0\xe1\x1e\x01\x62\x06proto3')



_QUERYPARAMSREQUEST = DESCRIPTOR.message_types_by_name['QueryParamsRequest']
_QUERYPARAMSRESPONSE = DESCRIPTOR.message_types_by_name['QueryParamsResponse']
_QUERYPRICEREQUEST = DESCRIPTOR.message_types_by_name['QueryPriceRequest']
_QUERYPRICERESPONSE = DESCRIPTOR.message_types_by_name['QueryPriceResponse']
_QUERYPRICESREQUEST = DESCRIPTOR.message_types_by_name['QueryPricesRequest']
_QUERYPRICESRESPONSE = DESCRIPTOR.message_types_by_name['QueryPricesResponse']
_QUERYRAWPRICESREQUEST = DESCRIPTOR.message_types_by_name['QueryRawPricesRequest']
_QUERYRAWPRICESRESPONSE = DESCRIPTOR.message_types_by_name['QueryRawPricesResponse']
_QUERYORACLESREQUEST = DESCRIPTOR.message_types_by_name['QueryOraclesRequest']
_QUERYORACLESRESPONSE = DESCRIPTOR.message_types_by_name['QueryOraclesResponse']
_QUERYMARKETSREQUEST = DESCRIPTOR.message_types_by_name['QueryMarketsRequest']
_QUERYMARKETSRESPONSE = DESCRIPTOR.message_types_by_name['QueryMarketsResponse']
_POSTEDPRICERESPONSE = DESCRIPTOR.message_types_by_name['PostedPriceResponse']
_CURRENTPRICERESPONSE = DESCRIPTOR.message_types_by_name['CurrentPriceResponse']
_MARKET = DESCRIPTOR.message_types_by_name['Market']
QueryParamsRequest = _reflection.GeneratedProtocolMessageType('QueryParamsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMSREQUEST,
  '__module__' : 'pricefeed.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.QueryParamsRequest)
  })
_sym_db.RegisterMessage(QueryParamsRequest)

QueryParamsResponse = _reflection.GeneratedProtocolMessageType('QueryParamsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMSRESPONSE,
  '__module__' : 'pricefeed.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.QueryParamsResponse)
  })
_sym_db.RegisterMessage(QueryParamsResponse)

QueryPriceRequest = _reflection.GeneratedProtocolMessageType('QueryPriceRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPRICEREQUEST,
  '__module__' : 'pricefeed.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.QueryPriceRequest)
  })
_sym_db.RegisterMessage(QueryPriceRequest)

QueryPriceResponse = _reflection.GeneratedProtocolMessageType('QueryPriceResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPRICERESPONSE,
  '__module__' : 'pricefeed.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.QueryPriceResponse)
  })
_sym_db.RegisterMessage(QueryPriceResponse)

QueryPricesRequest = _reflection.GeneratedProtocolMessageType('QueryPricesRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPRICESREQUEST,
  '__module__' : 'pricefeed.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.QueryPricesRequest)
  })
_sym_db.RegisterMessage(QueryPricesRequest)

QueryPricesResponse = _reflection.GeneratedProtocolMessageType('QueryPricesResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPRICESRESPONSE,
  '__module__' : 'pricefeed.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.QueryPricesResponse)
  })
_sym_db.RegisterMessage(QueryPricesResponse)

QueryRawPricesRequest = _reflection.GeneratedProtocolMessageType('QueryRawPricesRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYRAWPRICESREQUEST,
  '__module__' : 'pricefeed.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.QueryRawPricesRequest)
  })
_sym_db.RegisterMessage(QueryRawPricesRequest)

QueryRawPricesResponse = _reflection.GeneratedProtocolMessageType('QueryRawPricesResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYRAWPRICESRESPONSE,
  '__module__' : 'pricefeed.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.QueryRawPricesResponse)
  })
_sym_db.RegisterMessage(QueryRawPricesResponse)

QueryOraclesRequest = _reflection.GeneratedProtocolMessageType('QueryOraclesRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYORACLESREQUEST,
  '__module__' : 'pricefeed.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.QueryOraclesRequest)
  })
_sym_db.RegisterMessage(QueryOraclesRequest)

QueryOraclesResponse = _reflection.GeneratedProtocolMessageType('QueryOraclesResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYORACLESRESPONSE,
  '__module__' : 'pricefeed.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.QueryOraclesResponse)
  })
_sym_db.RegisterMessage(QueryOraclesResponse)

QueryMarketsRequest = _reflection.GeneratedProtocolMessageType('QueryMarketsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMARKETSREQUEST,
  '__module__' : 'pricefeed.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.QueryMarketsRequest)
  })
_sym_db.RegisterMessage(QueryMarketsRequest)

QueryMarketsResponse = _reflection.GeneratedProtocolMessageType('QueryMarketsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMARKETSRESPONSE,
  '__module__' : 'pricefeed.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.QueryMarketsResponse)
  })
_sym_db.RegisterMessage(QueryMarketsResponse)

PostedPriceResponse = _reflection.GeneratedProtocolMessageType('PostedPriceResponse', (_message.Message,), {
  'DESCRIPTOR' : _POSTEDPRICERESPONSE,
  '__module__' : 'pricefeed.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.PostedPriceResponse)
  })
_sym_db.RegisterMessage(PostedPriceResponse)

CurrentPriceResponse = _reflection.GeneratedProtocolMessageType('CurrentPriceResponse', (_message.Message,), {
  'DESCRIPTOR' : _CURRENTPRICERESPONSE,
  '__module__' : 'pricefeed.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.CurrentPriceResponse)
  })
_sym_db.RegisterMessage(CurrentPriceResponse)

Market = _reflection.GeneratedProtocolMessageType('Market', (_message.Message,), {
  'DESCRIPTOR' : _MARKET,
  '__module__' : 'pricefeed.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.Market)
  })
_sym_db.RegisterMessage(Market)

_QUERY = DESCRIPTOR.services_by_name['Query']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/NibiruChain/nibiru/x/pricefeed/types\250\342\036\001\340\341\036\001'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERYPARAMSRESPONSE._options = None
  _QUERYPARAMSRESPONSE._serialized_options = b'\210\240\037\000'
  _QUERYPRICEREQUEST._options = None
  _QUERYPRICEREQUEST._serialized_options = b'\210\240\037\000'
  _QUERYPRICERESPONSE.fields_by_name['price']._options = None
  _QUERYPRICERESPONSE.fields_by_name['price']._serialized_options = b'\310\336\037\000'
  _QUERYPRICERESPONSE._options = None
  _QUERYPRICERESPONSE._serialized_options = b'\210\240\037\000'
  _QUERYPRICESRESPONSE.fields_by_name['prices']._options = None
  _QUERYPRICESRESPONSE.fields_by_name['prices']._serialized_options = b'\252\337\037\025CurrentPriceResponses\310\336\037\000'
  _QUERYPRICESRESPONSE._options = None
  _QUERYPRICESRESPONSE._serialized_options = b'\210\240\037\000'
  _QUERYRAWPRICESREQUEST._options = None
  _QUERYRAWPRICESREQUEST._serialized_options = b'\210\240\037\000'
  _QUERYRAWPRICESRESPONSE.fields_by_name['raw_prices']._options = None
  _QUERYRAWPRICESRESPONSE.fields_by_name['raw_prices']._serialized_options = b'\252\337\037\024PostedPriceResponses\310\336\037\000'
  _QUERYRAWPRICESRESPONSE._options = None
  _QUERYRAWPRICESRESPONSE._serialized_options = b'\210\240\037\000'
  _QUERYORACLESREQUEST._options = None
  _QUERYORACLESREQUEST._serialized_options = b'\210\240\037\000'
  _QUERYORACLESRESPONSE._options = None
  _QUERYORACLESRESPONSE._serialized_options = b'\210\240\037\000'
  _QUERYMARKETSRESPONSE.fields_by_name['markets']._options = None
  _QUERYMARKETSRESPONSE.fields_by_name['markets']._serialized_options = b'\252\337\037\007Markets\310\336\037\000'
  _QUERYMARKETSRESPONSE._options = None
  _QUERYMARKETSRESPONSE._serialized_options = b'\210\240\037\000'
  _POSTEDPRICERESPONSE.fields_by_name['pair_id']._options = None
  _POSTEDPRICERESPONSE.fields_by_name['pair_id']._serialized_options = b'\342\336\037\006PairID'
  _POSTEDPRICERESPONSE.fields_by_name['price']._options = None
  _POSTEDPRICERESPONSE.fields_by_name['price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _POSTEDPRICERESPONSE.fields_by_name['expiry']._options = None
  _POSTEDPRICERESPONSE.fields_by_name['expiry']._serialized_options = b'\220\337\037\001\310\336\037\000'
  _CURRENTPRICERESPONSE.fields_by_name['pair_id']._options = None
  _CURRENTPRICERESPONSE.fields_by_name['pair_id']._serialized_options = b'\342\336\037\006PairID'
  _CURRENTPRICERESPONSE.fields_by_name['price']._options = None
  _CURRENTPRICERESPONSE.fields_by_name['price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MARKET.fields_by_name['pair_id']._options = None
  _MARKET.fields_by_name['pair_id']._serialized_options = b'\342\336\037\006PairID'
  _QUERY.methods_by_name['QueryParams']._options = None
  _QUERY.methods_by_name['QueryParams']._serialized_options = b'\202\323\344\223\002\"\022 /nibiru/pricefeed/v1beta1/params'
  _QUERY.methods_by_name['QueryPrice']._options = None
  _QUERY.methods_by_name['QueryPrice']._serialized_options = b'\202\323\344\223\002,\022*/nibiru/pricefeed/v1beta1/prices/{pair_id}'
  _QUERY.methods_by_name['QueryPrices']._options = None
  _QUERY.methods_by_name['QueryPrices']._serialized_options = b'\202\323\344\223\002\"\022 /nibiru/pricefeed/v1beta1/prices'
  _QUERY.methods_by_name['QueryRawPrices']._options = None
  _QUERY.methods_by_name['QueryRawPrices']._serialized_options = b'\202\323\344\223\002/\022-/nibiru/pricefeed/v1beta1/rawprices/{pair_id}'
  _QUERY.methods_by_name['QueryOracles']._options = None
  _QUERY.methods_by_name['QueryOracles']._serialized_options = b'\202\323\344\223\002-\022+/nibiru/pricefeed/v1beta1/oracles/{pair_id}'
  _QUERY.methods_by_name['QueryMarkets']._options = None
  _QUERY.methods_by_name['QueryMarkets']._serialized_options = b'\202\323\344\223\002#\022!/nibiru/pricefeed/v1beta1/markets'
  _QUERYPARAMSREQUEST._serialized_start=155
  _QUERYPARAMSREQUEST._serialized_end=175
  _QUERYPARAMSRESPONSE._serialized_start=177
  _QUERYPARAMSRESPONSE._serialized_end=255
  _QUERYPRICEREQUEST._serialized_start=257
  _QUERYPRICEREQUEST._serialized_end=299
  _QUERYPRICERESPONSE._serialized_start=301
  _QUERYPRICERESPONSE._serialized_end=391
  _QUERYPRICESREQUEST._serialized_start=393
  _QUERYPRICESREQUEST._serialized_end=413
  _QUERYPRICESRESPONSE._serialized_start=415
  _QUERYPRICESRESPONSE._serialized_end=532
  _QUERYRAWPRICESREQUEST._serialized_start=534
  _QUERYRAWPRICESREQUEST._serialized_end=580
  _QUERYRAWPRICESRESPONSE._serialized_start=582
  _QUERYRAWPRICESRESPONSE._serialized_end=704
  _QUERYORACLESREQUEST._serialized_start=706
  _QUERYORACLESREQUEST._serialized_end=750
  _QUERYORACLESRESPONSE._serialized_start=752
  _QUERYORACLESRESPONSE._serialized_end=797
  _QUERYMARKETSREQUEST._serialized_start=799
  _QUERYMARKETSREQUEST._serialized_end=820
  _QUERYMARKETSRESPONSE._serialized_start=822
  _QUERYMARKETSRESPONSE._serialized_end=913
  _POSTEDPRICERESPONSE._serialized_start=916
  _POSTEDPRICERESPONSE._serialized_end=1107
  _CURRENTPRICERESPONSE._serialized_start=1109
  _CURRENTPRICERESPONSE._serialized_end=1223
  _MARKET._serialized_start=1225
  _MARKET._serialized_end=1295
  _QUERY._serialized_start=1298
  _QUERY._serialized_end=2198
# @@protoc_insertion_point(module_scope)
