# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pricefeed/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pricefeed import params_pb2 as pricefeed_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17pricefeed/genesis.proto\x12\x13nibiru.pricefeed.v1\x1a\x14gogoproto/gogo.proto\x1a\x16pricefeed/params.proto\"\xa9\x01\n\x0cGenesisState\x12\x31\n\x06params\x18\x01 \x01(\x0b\x32\x1b.nibiru.pricefeed.v1.ParamsB\x04\xc8\xde\x1f\x00\x12M\n\rposted_prices\x18\x02 \x03(\x0b\x32 .nibiru.pricefeed.v1.PostedPriceB\x14\xaa\xdf\x1f\x0cPostedPrices\xc8\xde\x1f\x00\x12\x17\n\x0fgenesis_oracles\x18\x03 \x03(\tB1Z/github.com/NibiruChain/nibiru/x/pricefeed/typesb\x06proto3')



_GENESISSTATE = DESCRIPTOR.message_types_by_name['GenesisState']
GenesisState = _reflection.GeneratedProtocolMessageType('GenesisState', (_message.Message,), {
  'DESCRIPTOR' : _GENESISSTATE,
  '__module__' : 'pricefeed.genesis_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.GenesisState)
  })
_sym_db.RegisterMessage(GenesisState)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/NibiruChain/nibiru/x/pricefeed/types'
  _GENESISSTATE.fields_by_name['params']._options = None
  _GENESISSTATE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['posted_prices']._options = None
  _GENESISSTATE.fields_by_name['posted_prices']._serialized_options = b'\252\337\037\014PostedPrices\310\336\037\000'
  _GENESISSTATE._serialized_start=95
  _GENESISSTATE._serialized_end=264
# @@protoc_insertion_point(module_scope)
