# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vpool/v1/params.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15vpool/v1/params.proto\x12\x0fnibiru.vpool.v1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x19\x63osmos_proto/cosmos.proto\"\x0e\n\x06Params:\x04\x98\xa0\x1f\x00\"\xf1\x01\n\x0b\x43urrentTWAP\x12\x1b\n\x07pair_id\x18\x01 \x01(\tB\n\xe2\xde\x1f\x06PairID\x12\x41\n\tnumerator\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x43\n\x0b\x64\x65nominator\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12=\n\x05price\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x42-Z+github.com/NibiruChain/nibiru/x/vpool/typesb\x06proto3')



_PARAMS = DESCRIPTOR.message_types_by_name['Params']
_CURRENTTWAP = DESCRIPTOR.message_types_by_name['CurrentTWAP']
Params = _reflection.GeneratedProtocolMessageType('Params', (_message.Message,), {
  'DESCRIPTOR' : _PARAMS,
  '__module__' : 'vpool.v1.params_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.vpool.v1.Params)
  })
_sym_db.RegisterMessage(Params)

CurrentTWAP = _reflection.GeneratedProtocolMessageType('CurrentTWAP', (_message.Message,), {
  'DESCRIPTOR' : _CURRENTTWAP,
  '__module__' : 'vpool.v1.params_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.vpool.v1.CurrentTWAP)
  })
_sym_db.RegisterMessage(CurrentTWAP)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/NibiruChain/nibiru/x/vpool/types'
  _PARAMS._options = None
  _PARAMS._serialized_options = b'\230\240\037\000'
  _CURRENTTWAP.fields_by_name['pair_id']._options = None
  _CURRENTTWAP.fields_by_name['pair_id']._serialized_options = b'\342\336\037\006PairID'
  _CURRENTTWAP.fields_by_name['numerator']._options = None
  _CURRENTTWAP.fields_by_name['numerator']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _CURRENTTWAP.fields_by_name['denominator']._options = None
  _CURRENTTWAP.fields_by_name['denominator']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _CURRENTTWAP.fields_by_name['price']._options = None
  _CURRENTTWAP.fields_by_name['price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS._serialized_start=123
  _PARAMS._serialized_end=137
  _CURRENTTWAP._serialized_start=140
  _CURRENTTWAP._serialized_end=381
# @@protoc_insertion_point(module_scope)
