# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/feegrant/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.feegrant.v1beta1 import feegrant_pb2 as cosmos_dot_feegrant_dot_v1beta1_dot_feegrant__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#cosmos/feegrant/v1beta1/query.proto\x12\x17\x63osmos.feegrant.v1beta1\x1a&cosmos/feegrant/v1beta1/feegrant.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1cgoogle/api/annotations.proto\"9\n\x15QueryAllowanceRequest\x12\x0f\n\x07granter\x18\x01 \x01(\t\x12\x0f\n\x07grantee\x18\x02 \x01(\t\"K\n\x16QueryAllowanceResponse\x12\x31\n\tallowance\x18\x01 \x01(\x0b\x32\x1e.cosmos.feegrant.v1beta1.Grant\"e\n\x16QueryAllowancesRequest\x12\x0f\n\x07grantee\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x8a\x01\n\x17QueryAllowancesResponse\x12\x32\n\nallowances\x18\x01 \x03(\x0b\x32\x1e.cosmos.feegrant.v1beta1.Grant\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"n\n\x1fQueryAllowancesByGranterRequest\x12\x0f\n\x07granter\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x93\x01\n QueryAllowancesByGranterResponse\x12\x32\n\nallowances\x18\x01 \x03(\x0b\x32\x1e.cosmos.feegrant.v1beta1.Grant\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse2\x9f\x04\n\x05Query\x12\xac\x01\n\tAllowance\x12..cosmos.feegrant.v1beta1.QueryAllowanceRequest\x1a/.cosmos.feegrant.v1beta1.QueryAllowanceResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/cosmos/feegrant/v1beta1/allowance/{granter}/{grantee}\x12\xa6\x01\n\nAllowances\x12/.cosmos.feegrant.v1beta1.QueryAllowancesRequest\x1a\x30.cosmos.feegrant.v1beta1.QueryAllowancesResponse\"5\x82\xd3\xe4\x93\x02/\x12-/cosmos/feegrant/v1beta1/allowances/{grantee}\x12\xbd\x01\n\x13\x41llowancesByGranter\x12\x38.cosmos.feegrant.v1beta1.QueryAllowancesByGranterRequest\x1a\x39.cosmos.feegrant.v1beta1.QueryAllowancesByGranterResponse\"1\x82\xd3\xe4\x93\x02+\x12)/cosmos/feegrant/v1beta1/issued/{granter}B)Z\'github.com/cosmos/cosmos-sdk/x/feegrantb\x06proto3')



_QUERYALLOWANCEREQUEST = DESCRIPTOR.message_types_by_name['QueryAllowanceRequest']
_QUERYALLOWANCERESPONSE = DESCRIPTOR.message_types_by_name['QueryAllowanceResponse']
_QUERYALLOWANCESREQUEST = DESCRIPTOR.message_types_by_name['QueryAllowancesRequest']
_QUERYALLOWANCESRESPONSE = DESCRIPTOR.message_types_by_name['QueryAllowancesResponse']
_QUERYALLOWANCESBYGRANTERREQUEST = DESCRIPTOR.message_types_by_name['QueryAllowancesByGranterRequest']
_QUERYALLOWANCESBYGRANTERRESPONSE = DESCRIPTOR.message_types_by_name['QueryAllowancesByGranterResponse']
QueryAllowanceRequest = _reflection.GeneratedProtocolMessageType('QueryAllowanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYALLOWANCEREQUEST,
  '__module__' : 'cosmos.feegrant.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.feegrant.v1beta1.QueryAllowanceRequest)
  })
_sym_db.RegisterMessage(QueryAllowanceRequest)

QueryAllowanceResponse = _reflection.GeneratedProtocolMessageType('QueryAllowanceResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYALLOWANCERESPONSE,
  '__module__' : 'cosmos.feegrant.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.feegrant.v1beta1.QueryAllowanceResponse)
  })
_sym_db.RegisterMessage(QueryAllowanceResponse)

QueryAllowancesRequest = _reflection.GeneratedProtocolMessageType('QueryAllowancesRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYALLOWANCESREQUEST,
  '__module__' : 'cosmos.feegrant.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.feegrant.v1beta1.QueryAllowancesRequest)
  })
_sym_db.RegisterMessage(QueryAllowancesRequest)

QueryAllowancesResponse = _reflection.GeneratedProtocolMessageType('QueryAllowancesResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYALLOWANCESRESPONSE,
  '__module__' : 'cosmos.feegrant.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.feegrant.v1beta1.QueryAllowancesResponse)
  })
_sym_db.RegisterMessage(QueryAllowancesResponse)

QueryAllowancesByGranterRequest = _reflection.GeneratedProtocolMessageType('QueryAllowancesByGranterRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYALLOWANCESBYGRANTERREQUEST,
  '__module__' : 'cosmos.feegrant.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.feegrant.v1beta1.QueryAllowancesByGranterRequest)
  })
_sym_db.RegisterMessage(QueryAllowancesByGranterRequest)

QueryAllowancesByGranterResponse = _reflection.GeneratedProtocolMessageType('QueryAllowancesByGranterResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYALLOWANCESBYGRANTERRESPONSE,
  '__module__' : 'cosmos.feegrant.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.feegrant.v1beta1.QueryAllowancesByGranterResponse)
  })
_sym_db.RegisterMessage(QueryAllowancesByGranterResponse)

_QUERY = DESCRIPTOR.services_by_name['Query']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\'github.com/cosmos/cosmos-sdk/x/feegrant'
  _QUERY.methods_by_name['Allowance']._options = None
  _QUERY.methods_by_name['Allowance']._serialized_options = b'\202\323\344\223\0028\0226/cosmos/feegrant/v1beta1/allowance/{granter}/{grantee}'
  _QUERY.methods_by_name['Allowances']._options = None
  _QUERY.methods_by_name['Allowances']._serialized_options = b'\202\323\344\223\002/\022-/cosmos/feegrant/v1beta1/allowances/{grantee}'
  _QUERY.methods_by_name['AllowancesByGranter']._options = None
  _QUERY.methods_by_name['AllowancesByGranter']._serialized_options = b'\202\323\344\223\002+\022)/cosmos/feegrant/v1beta1/issued/{granter}'
  _QUERYALLOWANCEREQUEST._serialized_start=178
  _QUERYALLOWANCEREQUEST._serialized_end=235
  _QUERYALLOWANCERESPONSE._serialized_start=237
  _QUERYALLOWANCERESPONSE._serialized_end=312
  _QUERYALLOWANCESREQUEST._serialized_start=314
  _QUERYALLOWANCESREQUEST._serialized_end=415
  _QUERYALLOWANCESRESPONSE._serialized_start=418
  _QUERYALLOWANCESRESPONSE._serialized_end=556
  _QUERYALLOWANCESBYGRANTERREQUEST._serialized_start=558
  _QUERYALLOWANCESBYGRANTERREQUEST._serialized_end=668
  _QUERYALLOWANCESBYGRANTERRESPONSE._serialized_start=671
  _QUERYALLOWANCESBYGRANTERRESPONSE._serialized_end=818
  _QUERY._serialized_start=821
  _QUERY._serialized_end=1364
# @@protoc_insertion_point(module_scope)
