# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/bank/v1beta1/bank.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63osmos/bank/v1beta1/bank.proto\x12\x13\x63osmos.bank.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\xb2\x01\n\x06Params\x12Y\n\x0csend_enabled\x18\x01 \x03(\x0b\x32 .cosmos.bank.v1beta1.SendEnabledB!\xf2\xde\x1f\x1dyaml:\"send_enabled,omitempty\"\x12G\n\x14\x64\x65\x66\x61ult_send_enabled\x18\x02 \x01(\x08\x42)\xf2\xde\x1f%yaml:\"default_send_enabled,omitempty\":\x04\x98\xa0\x1f\x00\"7\n\x0bSendEnabled\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08:\x08\xe8\xa0\x1f\x01\x98\xa0\x1f\x00\"~\n\x05Input\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12Z\n\x05\x63oins\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x7f\n\x06Output\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12Z\n\x05\x63oins\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xac\x01\n\x06Supply\x12Z\n\x05total\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:F\x18\x01\xe8\xa0\x1f\x01\x88\xa0\x1f\x00\xd2\xb4-8*github.com/cosmos/cosmos-sdk/x/bank/legacy/v040.SupplyI\"=\n\tDenomUnit\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x10\n\x08\x65xponent\x18\x02 \x01(\r\x12\x0f\n\x07\x61liases\x18\x03 \x03(\t\"\x91\x01\n\x08Metadata\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x33\n\x0b\x64\x65nom_units\x18\x02 \x03(\x0b\x32\x1e.cosmos.bank.v1beta1.DenomUnit\x12\x0c\n\x04\x62\x61se\x18\x03 \x01(\t\x12\x0f\n\x07\x64isplay\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0e\n\x06symbol\x18\x06 \x01(\tB+Z)github.com/cosmos/cosmos-sdk/x/bank/typesb\x06proto3')



_PARAMS = DESCRIPTOR.message_types_by_name['Params']
_SENDENABLED = DESCRIPTOR.message_types_by_name['SendEnabled']
_INPUT = DESCRIPTOR.message_types_by_name['Input']
_OUTPUT = DESCRIPTOR.message_types_by_name['Output']
_SUPPLY = DESCRIPTOR.message_types_by_name['Supply']
_DENOMUNIT = DESCRIPTOR.message_types_by_name['DenomUnit']
_METADATA = DESCRIPTOR.message_types_by_name['Metadata']
Params = _reflection.GeneratedProtocolMessageType('Params', (_message.Message,), {
  'DESCRIPTOR' : _PARAMS,
  '__module__' : 'cosmos.bank.v1beta1.bank_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.bank.v1beta1.Params)
  })
_sym_db.RegisterMessage(Params)

SendEnabled = _reflection.GeneratedProtocolMessageType('SendEnabled', (_message.Message,), {
  'DESCRIPTOR' : _SENDENABLED,
  '__module__' : 'cosmos.bank.v1beta1.bank_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.bank.v1beta1.SendEnabled)
  })
_sym_db.RegisterMessage(SendEnabled)

Input = _reflection.GeneratedProtocolMessageType('Input', (_message.Message,), {
  'DESCRIPTOR' : _INPUT,
  '__module__' : 'cosmos.bank.v1beta1.bank_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.bank.v1beta1.Input)
  })
_sym_db.RegisterMessage(Input)

Output = _reflection.GeneratedProtocolMessageType('Output', (_message.Message,), {
  'DESCRIPTOR' : _OUTPUT,
  '__module__' : 'cosmos.bank.v1beta1.bank_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.bank.v1beta1.Output)
  })
_sym_db.RegisterMessage(Output)

Supply = _reflection.GeneratedProtocolMessageType('Supply', (_message.Message,), {
  'DESCRIPTOR' : _SUPPLY,
  '__module__' : 'cosmos.bank.v1beta1.bank_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.bank.v1beta1.Supply)
  })
_sym_db.RegisterMessage(Supply)

DenomUnit = _reflection.GeneratedProtocolMessageType('DenomUnit', (_message.Message,), {
  'DESCRIPTOR' : _DENOMUNIT,
  '__module__' : 'cosmos.bank.v1beta1.bank_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.bank.v1beta1.DenomUnit)
  })
_sym_db.RegisterMessage(DenomUnit)

Metadata = _reflection.GeneratedProtocolMessageType('Metadata', (_message.Message,), {
  'DESCRIPTOR' : _METADATA,
  '__module__' : 'cosmos.bank.v1beta1.bank_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.bank.v1beta1.Metadata)
  })
_sym_db.RegisterMessage(Metadata)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/bank/types'
  _PARAMS.fields_by_name['send_enabled']._options = None
  _PARAMS.fields_by_name['send_enabled']._serialized_options = b'\362\336\037\035yaml:\"send_enabled,omitempty\"'
  _PARAMS.fields_by_name['default_send_enabled']._options = None
  _PARAMS.fields_by_name['default_send_enabled']._serialized_options = b'\362\336\037%yaml:\"default_send_enabled,omitempty\"'
  _PARAMS._options = None
  _PARAMS._serialized_options = b'\230\240\037\000'
  _SENDENABLED._options = None
  _SENDENABLED._serialized_options = b'\350\240\037\001\230\240\037\000'
  _INPUT.fields_by_name['coins']._options = None
  _INPUT.fields_by_name['coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _INPUT._options = None
  _INPUT._serialized_options = b'\350\240\037\000\210\240\037\000'
  _OUTPUT.fields_by_name['coins']._options = None
  _OUTPUT.fields_by_name['coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _OUTPUT._options = None
  _OUTPUT._serialized_options = b'\350\240\037\000\210\240\037\000'
  _SUPPLY.fields_by_name['total']._options = None
  _SUPPLY.fields_by_name['total']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _SUPPLY._options = None
  _SUPPLY._serialized_options = b'\030\001\350\240\037\001\210\240\037\000\322\264-8*github.com/cosmos/cosmos-sdk/x/bank/legacy/v040.SupplyI'
  _PARAMS._serialized_start=137
  _PARAMS._serialized_end=315
  _SENDENABLED._serialized_start=317
  _SENDENABLED._serialized_end=372
  _INPUT._serialized_start=374
  _INPUT._serialized_end=500
  _OUTPUT._serialized_start=502
  _OUTPUT._serialized_end=629
  _SUPPLY._serialized_start=632
  _SUPPLY._serialized_end=804
  _DENOMUNIT._serialized_start=806
  _DENOMUNIT._serialized_end=867
  _METADATA._serialized_start=870
  _METADATA._serialized_end=1015
# @@protoc_insertion_point(module_scope)
