# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x63ommon/common.proto\x12\rnibiru.common\x1a\x14gogoproto/gogo.proto\"1\n\tAssetPair\x12\x0e\n\x06token0\x18\x01 \x01(\t\x12\x0e\n\x06token1\x18\x02 \x01(\t:\x04\x88\xa0\x1f\x00\x42\x34Z&github.com/NibiruChain/nibiru/x/common\xa8\xe2\x1e\x01\xe0\xe1\x1e\x01\xd8\xe1\x1e\x00\x62\x06proto3')



_ASSETPAIR = DESCRIPTOR.message_types_by_name['AssetPair']
AssetPair = _reflection.GeneratedProtocolMessageType('AssetPair', (_message.Message,), {
  'DESCRIPTOR' : _ASSETPAIR,
  '__module__' : 'common.common_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.common.AssetPair)
  })
_sym_db.RegisterMessage(AssetPair)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z&github.com/NibiruChain/nibiru/x/common\250\342\036\001\340\341\036\001\330\341\036\000'
  _ASSETPAIR._options = None
  _ASSETPAIR._serialized_options = b'\210\240\037\000'
  _ASSETPAIR._serialized_start=60
  _ASSETPAIR._serialized_end=109
# @@protoc_insertion_point(module_scope)
