# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pricefeed/gov.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13pricefeed/gov.proto\x12\x13nibiru.pricefeed.v1\x1a\x14gogoproto/gogo.proto\"}\n\x11\x41\x64\x64OracleProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12#\n\x07oracles\x18\x03 \x03(\tB\x12\xf2\xde\x1f\x0eyaml:\"oracles\"\x12\x1f\n\x05pairs\x18\x04 \x03(\tB\x10\xf2\xde\x1f\x0cyaml:\"pairs\"B1Z/github.com/NibiruChain/nibiru/x/pricefeed/typesb\x06proto3')



_ADDORACLEPROPOSAL = DESCRIPTOR.message_types_by_name['AddOracleProposal']
AddOracleProposal = _reflection.GeneratedProtocolMessageType('AddOracleProposal', (_message.Message,), {
  'DESCRIPTOR' : _ADDORACLEPROPOSAL,
  '__module__' : 'pricefeed.gov_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.AddOracleProposal)
  })
_sym_db.RegisterMessage(AddOracleProposal)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/NibiruChain/nibiru/x/pricefeed/types'
  _ADDORACLEPROPOSAL.fields_by_name['oracles']._options = None
  _ADDORACLEPROPOSAL.fields_by_name['oracles']._serialized_options = b'\362\336\037\016yaml:\"oracles\"'
  _ADDORACLEPROPOSAL.fields_by_name['pairs']._options = None
  _ADDORACLEPROPOSAL.fields_by_name['pairs']._serialized_options = b'\362\336\037\014yaml:\"pairs\"'
  _ADDORACLEPROPOSAL._serialized_start=66
  _ADDORACLEPROPOSAL._serialized_end=191
# @@protoc_insertion_point(module_scope)
