# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/authz/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from cosmos.base.abci.v1beta1 import abci_pb2 as cosmos_dot_base_dot_abci_dot_v1beta1_dot_abci__pb2
from cosmos.authz.v1beta1 import authz_pb2 as cosmos_dot_authz_dot_v1beta1_dot_authz__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x63osmos/authz/v1beta1/tx.proto\x12\x14\x63osmos.authz.v1beta1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\x1a#cosmos/base/abci/v1beta1/abci.proto\x1a cosmos/authz/v1beta1/authz.proto\"^\n\x08MsgGrant\x12\x0f\n\x07granter\x18\x01 \x01(\t\x12\x0f\n\x07grantee\x18\x02 \x01(\t\x12\x30\n\x05grant\x18\x03 \x01(\x0b\x32\x1b.cosmos.authz.v1beta1.GrantB\x04\xc8\xde\x1f\x00\"\"\n\x0fMsgExecResponse\x12\x0f\n\x07results\x18\x01 \x03(\x0c\"`\n\x07MsgExec\x12\x0f\n\x07grantee\x18\x01 \x01(\t\x12\x44\n\x04msgs\x18\x02 \x03(\x0b\x32\x14.google.protobuf.AnyB \xca\xb4-\x1csdk.Msg, authz.Authorization\"\x12\n\x10MsgGrantResponse\"C\n\tMsgRevoke\x12\x0f\n\x07granter\x18\x01 \x01(\t\x12\x0f\n\x07grantee\x18\x02 \x01(\t\x12\x14\n\x0cmsg_type_url\x18\x03 \x01(\t\"\x13\n\x11MsgRevokeResponse2\xf8\x01\n\x03Msg\x12O\n\x05Grant\x12\x1e.cosmos.authz.v1beta1.MsgGrant\x1a&.cosmos.authz.v1beta1.MsgGrantResponse\x12L\n\x04\x45xec\x12\x1d.cosmos.authz.v1beta1.MsgExec\x1a%.cosmos.authz.v1beta1.MsgExecResponse\x12R\n\x06Revoke\x12\x1f.cosmos.authz.v1beta1.MsgRevoke\x1a\'.cosmos.authz.v1beta1.MsgRevokeResponseB*Z$github.com/cosmos/cosmos-sdk/x/authz\xc8\xe1\x1e\x00\x62\x06proto3')



_MSGGRANT = DESCRIPTOR.message_types_by_name['MsgGrant']
_MSGEXECRESPONSE = DESCRIPTOR.message_types_by_name['MsgExecResponse']
_MSGEXEC = DESCRIPTOR.message_types_by_name['MsgExec']
_MSGGRANTRESPONSE = DESCRIPTOR.message_types_by_name['MsgGrantResponse']
_MSGREVOKE = DESCRIPTOR.message_types_by_name['MsgRevoke']
_MSGREVOKERESPONSE = DESCRIPTOR.message_types_by_name['MsgRevokeResponse']
MsgGrant = _reflection.GeneratedProtocolMessageType('MsgGrant', (_message.Message,), {
  'DESCRIPTOR' : _MSGGRANT,
  '__module__' : 'cosmos.authz.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.authz.v1beta1.MsgGrant)
  })
_sym_db.RegisterMessage(MsgGrant)

MsgExecResponse = _reflection.GeneratedProtocolMessageType('MsgExecResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGEXECRESPONSE,
  '__module__' : 'cosmos.authz.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.authz.v1beta1.MsgExecResponse)
  })
_sym_db.RegisterMessage(MsgExecResponse)

MsgExec = _reflection.GeneratedProtocolMessageType('MsgExec', (_message.Message,), {
  'DESCRIPTOR' : _MSGEXEC,
  '__module__' : 'cosmos.authz.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.authz.v1beta1.MsgExec)
  })
_sym_db.RegisterMessage(MsgExec)

MsgGrantResponse = _reflection.GeneratedProtocolMessageType('MsgGrantResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGGRANTRESPONSE,
  '__module__' : 'cosmos.authz.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.authz.v1beta1.MsgGrantResponse)
  })
_sym_db.RegisterMessage(MsgGrantResponse)

MsgRevoke = _reflection.GeneratedProtocolMessageType('MsgRevoke', (_message.Message,), {
  'DESCRIPTOR' : _MSGREVOKE,
  '__module__' : 'cosmos.authz.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.authz.v1beta1.MsgRevoke)
  })
_sym_db.RegisterMessage(MsgRevoke)

MsgRevokeResponse = _reflection.GeneratedProtocolMessageType('MsgRevokeResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGREVOKERESPONSE,
  '__module__' : 'cosmos.authz.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.authz.v1beta1.MsgRevokeResponse)
  })
_sym_db.RegisterMessage(MsgRevokeResponse)

_MSG = DESCRIPTOR.services_by_name['Msg']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z$github.com/cosmos/cosmos-sdk/x/authz\310\341\036\000'
  _MSGGRANT.fields_by_name['grant']._options = None
  _MSGGRANT.fields_by_name['grant']._serialized_options = b'\310\336\037\000'
  _MSGEXEC.fields_by_name['msgs']._options = None
  _MSGEXEC.fields_by_name['msgs']._serialized_options = b'\312\264-\034sdk.Msg, authz.Authorization'
  _MSGGRANT._serialized_start=235
  _MSGGRANT._serialized_end=329
  _MSGEXECRESPONSE._serialized_start=331
  _MSGEXECRESPONSE._serialized_end=365
  _MSGEXEC._serialized_start=367
  _MSGEXEC._serialized_end=463
  _MSGGRANTRESPONSE._serialized_start=465
  _MSGGRANTRESPONSE._serialized_end=483
  _MSGREVOKE._serialized_start=485
  _MSGREVOKE._serialized_end=552
  _MSGREVOKERESPONSE._serialized_start=554
  _MSGREVOKERESPONSE._serialized_end=573
  _MSG._serialized_start=576
  _MSG._serialized_end=824
# @@protoc_insertion_point(module_scope)
