# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/libs/bits/types.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n tendermint/libs/bits/types.proto\x12\x14tendermint.libs.bits\"\'\n\x08\x42itArray\x12\x0c\n\x04\x62its\x18\x01 \x01(\x03\x12\r\n\x05\x65lems\x18\x02 \x03(\x04\x42=Z;github.com/tendermint/tendermint/proto/tendermint/libs/bitsb\x06proto3')



_BITARRAY = DESCRIPTOR.message_types_by_name['BitArray']
BitArray = _reflection.GeneratedProtocolMessageType('BitArray', (_message.Message,), {
  'DESCRIPTOR' : _BITARRAY,
  '__module__' : 'tendermint.libs.bits.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.libs.bits.BitArray)
  })
_sym_db.RegisterMessage(BitArray)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z;github.com/tendermint/tendermint/proto/tendermint/libs/bits'
  _BITARRAY._serialized_start=58
  _BITARRAY._serialized_end=97
# @@protoc_insertion_point(module_scope)
