# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pricefeed/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12pricefeed/tx.proto\x12\x13nibiru.pricefeed.v1\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/api/annotations.proto\"\xb7\x01\n\x0cMsgPostPrice\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12\x0e\n\x06token0\x18\x02 \x01(\t\x12\x0e\n\x06token1\x18\x03 \x01(\t\x12=\n\x05price\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x34\n\x06\x65xpiry\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\x90\xdf\x1f\x01\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\"\x16\n\x14MsgPostPriceResponse\"\xb3\x01\n\x16\x45ventOracleUpdatePrice\x12\x0f\n\x07pair_id\x18\x01 \x01(\t\x12\x0e\n\x06oracle\x18\x02 \x01(\t\x12\x42\n\npair_price\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x34\n\x06\x65xpiry\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\x90\xdf\x1f\x01\xc8\xde\x1f\x00\"l\n\x15\x45ventPairPriceUpdated\x12\x0f\n\x07pair_id\x18\x01 \x01(\t\x12\x42\n\npair_price\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x32\x86\x01\n\x03Msg\x12\x7f\n\tPostPrice\x12!.nibiru.pricefeed.v1.MsgPostPrice\x1a).nibiru.pricefeed.v1.MsgPostPriceResponse\"$\x82\xd3\xe4\x93\x02\x1e\"\x1c/nibiru/pricefeed/post-priceB9Z/github.com/NibiruChain/nibiru/x/pricefeed/types\xa8\xe2\x1e\x01\xe0\xe1\x1e\x01\x62\x06proto3')



_MSGPOSTPRICE = DESCRIPTOR.message_types_by_name['MsgPostPrice']
_MSGPOSTPRICERESPONSE = DESCRIPTOR.message_types_by_name['MsgPostPriceResponse']
_EVENTORACLEUPDATEPRICE = DESCRIPTOR.message_types_by_name['EventOracleUpdatePrice']
_EVENTPAIRPRICEUPDATED = DESCRIPTOR.message_types_by_name['EventPairPriceUpdated']
MsgPostPrice = _reflection.GeneratedProtocolMessageType('MsgPostPrice', (_message.Message,), {
  'DESCRIPTOR' : _MSGPOSTPRICE,
  '__module__' : 'pricefeed.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.MsgPostPrice)
  })
_sym_db.RegisterMessage(MsgPostPrice)

MsgPostPriceResponse = _reflection.GeneratedProtocolMessageType('MsgPostPriceResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGPOSTPRICERESPONSE,
  '__module__' : 'pricefeed.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.MsgPostPriceResponse)
  })
_sym_db.RegisterMessage(MsgPostPriceResponse)

EventOracleUpdatePrice = _reflection.GeneratedProtocolMessageType('EventOracleUpdatePrice', (_message.Message,), {
  'DESCRIPTOR' : _EVENTORACLEUPDATEPRICE,
  '__module__' : 'pricefeed.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.EventOracleUpdatePrice)
  })
_sym_db.RegisterMessage(EventOracleUpdatePrice)

EventPairPriceUpdated = _reflection.GeneratedProtocolMessageType('EventPairPriceUpdated', (_message.Message,), {
  'DESCRIPTOR' : _EVENTPAIRPRICEUPDATED,
  '__module__' : 'pricefeed.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.EventPairPriceUpdated)
  })
_sym_db.RegisterMessage(EventPairPriceUpdated)

_MSG = DESCRIPTOR.services_by_name['Msg']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/NibiruChain/nibiru/x/pricefeed/types\250\342\036\001\340\341\036\001'
  _MSGPOSTPRICE.fields_by_name['price']._options = None
  _MSGPOSTPRICE.fields_by_name['price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGPOSTPRICE.fields_by_name['expiry']._options = None
  _MSGPOSTPRICE.fields_by_name['expiry']._serialized_options = b'\220\337\037\001\310\336\037\000'
  _MSGPOSTPRICE._options = None
  _MSGPOSTPRICE._serialized_options = b'\210\240\037\000'
  _EVENTORACLEUPDATEPRICE.fields_by_name['pair_price']._options = None
  _EVENTORACLEUPDATEPRICE.fields_by_name['pair_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _EVENTORACLEUPDATEPRICE.fields_by_name['expiry']._options = None
  _EVENTORACLEUPDATEPRICE.fields_by_name['expiry']._serialized_options = b'\220\337\037\001\310\336\037\000'
  _EVENTPAIRPRICEUPDATED.fields_by_name['pair_price']._options = None
  _EVENTPAIRPRICEUPDATED.fields_by_name['pair_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSG.methods_by_name['PostPrice']._options = None
  _MSG.methods_by_name['PostPrice']._serialized_options = b'\202\323\344\223\002\036\"\034/nibiru/pricefeed/post-price'
  _MSGPOSTPRICE._serialized_start=129
  _MSGPOSTPRICE._serialized_end=312
  _MSGPOSTPRICERESPONSE._serialized_start=314
  _MSGPOSTPRICERESPONSE._serialized_end=336
  _EVENTORACLEUPDATEPRICE._serialized_start=339
  _EVENTORACLEUPDATEPRICE._serialized_end=518
  _EVENTPAIRPRICEUPDATED._serialized_start=520
  _EVENTPAIRPRICEUPDATED._serialized_end=628
  _MSG._serialized_start=631
  _MSG._serialized_end=765
# @@protoc_insertion_point(module_scope)
